@@ -9,13 +9,10 @@ TF_CPP_MIN_LOG_LEVEL 取值 3 ： 屏蔽通知信息、警告信息和报错信
 import tensorflow as tf
 
 info='this is a test for GPU'
+
 def gpu():
     tf_version=tf.__version__
     gpu=tf.config.list_physical_devices('GPU')
     return f'TensorFlow:{tf_version}\nGPU nummber:{len(gpu)}\nGPU Info:{gpu}'
 
-def hi(name):
 
-    return f'Name:{name}'
-print(gpu())
-print(hi('james'))
